==> rnelson0-certs-1.0.0.tar.gz: rnelson0-certs-1.0.0/CHANGELOG.md <==
# Change log

All notable changes to this project will be documented in this file. The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/) and this project adheres to [Semantic Versioning](http://semver.org).

## [v1.0.0](https://github.com/rnelson0/puppet-certs/tree/v1.0.0) (2019-12-27)

[Full Changelog](https://github.com/rnelson0/puppet-certs/compare/40389b8a66e644b543647b76d8e13cf8100e7474...v1.0.0)

### Added

- Remove puppet 3 testing, add puppet 5 testing [\#31](https://github.com/rnelson0/puppet-certs/pull/31) ([rnelson0](https://github.com/rnelson0))
- Update test configuration [\#23](https://github.com/rnelson0/puppet-certs/pull/23) ([rnelson0](https://github.com/rnelson0))
- Update README.md [\#18](https://github.com/rnelson0/puppet-certs/pull/18) ([rnelson0](https://github.com/rnelson0))
- Initial rspec fixtures [\#12](https://github.com/rnelson0/puppet-certs/pull/12) ([rnelson0](https://github.com/rnelson0))
- Improvements to match puppet style. [\#10](https://github.com/rnelson0/puppet-certs/pull/10) ([rnelson0](https://github.com/rnelson0))
- Empty class and trailing slashes [\#5](https://github.com/rnelson0/puppet-certs/pull/5) ([rnelson0](https://github.com/rnelson0))
- Update vhost\_spec.rb [\#4](https://github.com/rnelson0/puppet-certs/pull/4) ([paschdan](https://github.com/paschdan))

### UNCATEGORIZED PRS; GO LABEL THEM

- Pdkconvert [\#33](https://github.com/rnelson0/puppet-certs/pull/33) ([rnelson0](https://github.com/rnelson0))
- Use puppet-strings for documentation [\#32](https://github.com/rnelson0/puppet-certs/pull/32) ([rnelson0](https://github.com/rnelson0))
- Remove direct reference to semantic\_puppet [\#30](https://github.com/rnelson0/puppet-certs/pull/30) ([rnelson0](https://github.com/rnelson0))
- Modulesync [\#29](https://github.com/rnelson0/puppet-certs/pull/29) ([rnelson0](https://github.com/rnelson0))
- MSync Gemfile and Rakefile [\#28](https://github.com/rnelson0/puppet-certs/pull/28) ([rnelson0](https://github.com/rnelson0))
- Gemfile: Remove guard-rake from development group. [\#22](https://github.com/rnelson0/puppet-certs/pull/22) ([rnelson0](https://github.com/rnelson0))
- Update .travis.yml and Rakefile [\#21](https://github.com/rnelson0/puppet-certs/pull/21) ([rnelson0](https://github.com/rnelson0))
- August msync [\#20](https://github.com/rnelson0/puppet-certs/pull/20) ([rnelson0](https://github.com/rnelson0))
- Update from rnelson0's modulesync [\#19](https://github.com/rnelson0/puppet-certs/pull/19) ([rnelson0](https://github.com/rnelson0))
- Add hiera boilerplate \(testing an empty hiera config for errors or warnings\) [\#17](https://github.com/rnelson0/puppet-certs/pull/17) ([rnelson0](https://github.com/rnelson0))
- Build master branch as well as PRs [\#15](https://github.com/rnelson0/puppet-certs/pull/15) ([rnelson0](https://github.com/rnelson0))
- Add badges [\#14](https://github.com/rnelson0/puppet-certs/pull/14) ([rnelson0](https://github.com/rnelson0))
- Initial commit using Travis CI for testing [\#13](https://github.com/rnelson0/puppet-certs/pull/13) ([rnelson0](https://github.com/rnelson0))
- v0.6.2 - Update url to match renamed repo [\#11](https://github.com/rnelson0/puppet-certs/pull/11) ([rnelson0](https://github.com/rnelson0))
- Bump to v0.6.0 [\#9](https://github.com/rnelson0/puppet-certs/pull/9) ([rnelson0](https://github.com/rnelson0))
- Ready for the forge [\#7](https://github.com/rnelson0/puppet-certs/pull/7) ([rnelson0](https://github.com/rnelson0))
- Spec helper [\#6](https://github.com/rnelson0/puppet-certs/pull/6) ([rnelson0](https://github.com/rnelson0))
- Correct README.md's TOC [\#3](https://github.com/rnelson0/puppet-certs/pull/3) ([rnelson0](https://github.com/rnelson0))
- Create a proper README.md file [\#2](https://github.com/rnelson0/puppet-certs/pull/2) ([rnelson0](https://github.com/rnelson0))
- Certs modified to fail when included directly. [\#1](https://github.com/rnelson0/puppet-certs/pull/1) ([rnelson0](https://github.com/rnelson0))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/skywinder/Github-Changelog-Generator)*

==> rnelson0-certs-1.1.0.tar.gz: rnelson0-certs-1.1.0/CHANGELOG.md <==
# Change log

All notable changes to this project will be documented in this file. The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/) and this project adheres to [Semantic Versioning](http://semver.org).

## [v1.1.0](https://github.com/rnelson0/puppet-certs/tree/v1.1.0) (2020-09-30)

[Full Changelog](https://github.com/rnelson0/puppet-certs/compare/v1.0.0...v1.1.0)

### Added

- Updating contributing docs, mock\_with Rspec for future compatibility, and puppet-vault\_lookup dependency [\#36](https://github.com/rnelson0/puppet-certs/pull/36) ([ekingme](https://github.com/ekingme))
- Adding support for reading crt/key from Vault [\#35](https://github.com/rnelson0/puppet-certs/pull/35) ([ekingme](https://github.com/ekingme))

## [v1.0.0](https://github.com/rnelson0/puppet-certs/tree/v1.0.0) (2019-12-27)

[Full Changelog](https://github.com/rnelson0/puppet-certs/compare/40389b8a66e644b543647b76d8e13cf8100e7474...v1.0.0)

### Added

- Remove puppet 3 testing, add puppet 5 testing [\#31](https://github.com/rnelson0/puppet-certs/pull/31) ([rnelson0](https://github.com/rnelson0))
- Update test configuration [\#23](https://github.com/rnelson0/puppet-certs/pull/23) ([rnelson0](https://github.com/rnelson0))
- Update README.md [\#18](https://github.com/rnelson0/puppet-certs/pull/18) ([rnelson0](https://github.com/rnelson0))
- Initial rspec fixtures [\#12](https://github.com/rnelson0/puppet-certs/pull/12) ([rnelson0](https://github.com/rnelson0))
- Improvements to match puppet style. [\#10](https://github.com/rnelson0/puppet-certs/pull/10) ([rnelson0](https://github.com/rnelson0))
- Empty class and trailing slashes [\#5](https://github.com/rnelson0/puppet-certs/pull/5) ([rnelson0](https://github.com/rnelson0))
- Update vhost\_spec.rb [\#4](https://github.com/rnelson0/puppet-certs/pull/4) ([paschdan](https://github.com/paschdan))

### Fixed

- Remove direct reference to semantic\_puppet [\#30](https://github.com/rnelson0/puppet-certs/pull/30) ([rnelson0](https://github.com/rnelson0))
- Gemfile: Remove guard-rake from development group. [\#22](https://github.com/rnelson0/puppet-certs/pull/22) ([rnelson0](https://github.com/rnelson0))
- Bump to v0.6.0 [\#9](https://github.com/rnelson0/puppet-certs/pull/9) ([rnelson0](https://github.com/rnelson0))
- Certs modified to fail when included directly. [\#1](https://github.com/rnelson0/puppet-certs/pull/1) ([rnelson0](https://github.com/rnelson0))

### UNCATEGORIZED PRS; LABEL THEM ON GITHUB

- Release candidate for v1.0.0 [\#34](https://github.com/rnelson0/puppet-certs/pull/34) ([rnelson0](https://github.com/rnelson0))
- Pdkconvert [\#33](https://github.com/rnelson0/puppet-certs/pull/33) ([rnelson0](https://github.com/rnelson0))
- Use puppet-strings for documentation [\#32](https://github.com/rnelson0/puppet-certs/pull/32) ([rnelson0](https://github.com/rnelson0))
- Modulesync [\#29](https://github.com/rnelson0/puppet-certs/pull/29) ([rnelson0](https://github.com/rnelson0))
- MSync Gemfile and Rakefile [\#28](https://github.com/rnelson0/puppet-certs/pull/28) ([rnelson0](https://github.com/rnelson0))
- Update .travis.yml and Rakefile [\#21](https://github.com/rnelson0/puppet-certs/pull/21) ([rnelson0](https://github.com/rnelson0))
- August msync [\#20](https://github.com/rnelson0/puppet-certs/pull/20) ([rnelson0](https://github.com/rnelson0))
- Update from rnelson0's modulesync [\#19](https://github.com/rnelson0/puppet-certs/pull/19) ([rnelson0](https://github.com/rnelson0))
- Add hiera boilerplate \(testing an empty hiera config for errors or warnings\) [\#17](https://github.com/rnelson0/puppet-certs/pull/17) ([rnelson0](https://github.com/rnelson0))
- Build master branch as well as PRs [\#15](https://github.com/rnelson0/puppet-certs/pull/15) ([rnelson0](https://github.com/rnelson0))
- Add badges [\#14](https://github.com/rnelson0/puppet-certs/pull/14) ([rnelson0](https://github.com/rnelson0))
- Initial commit using Travis CI for testing [\#13](https://github.com/rnelson0/puppet-certs/pull/13) ([rnelson0](https://github.com/rnelson0))
- v0.6.2 - Update url to match renamed repo [\#11](https://github.com/rnelson0/puppet-certs/pull/11) ([rnelson0](https://github.com/rnelson0))
- Ready for the forge [\#7](https://github.com/rnelson0/puppet-certs/pull/7) ([rnelson0](https://github.com/rnelson0))
- Spec helper [\#6](https://github.com/rnelson0/puppet-certs/pull/6) ([rnelson0](https://github.com/rnelson0))
- Correct README.md's TOC [\#3](https://github.com/rnelson0/puppet-certs/pull/3) ([rnelson0](https://github.com/rnelson0))
- Create a proper README.md file [\#2](https://github.com/rnelson0/puppet-certs/pull/2) ([rnelson0](https://github.com/rnelson0))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/skywinder/Github-Changelog-Generator)*
